/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 06845
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1982
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE cigmorls  1='(1) More' 2='(2) Less' 3='(3) Same' 4='(4) No opinion'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtry    91='(91) NEVER SMOKED CIGARETTES' 94='(94) DONT KNOW' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER SMOKED CIGARETTES' 94='(94) DONT KNOW' ;
  VALUE avcig     1='(1) Less than 1' 2='(2) 1 - 5' 3='(3) Half pack' 4='(4) Pack'
                  5='(5) 1 1/2 packs' 6='(6) Two plus' 91='(91) NEVER SMOKED CIGARETTES'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE morlsmj   1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlssed  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlstrn  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlsamp  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlscoc  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlslsd  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlsher  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addalc    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addmj     1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addsed    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addtran   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addamp    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addcoc    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addlsd    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addher    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addnone   1='(1) Nothing circled above' 2='(2) 1 or more drugs circled' ;
  VALUE alctry    81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but more than mth ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically imputed'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpref   1='(1) Beer' 2='(2) Wine' 3='(3) Liquor'
                  4='(4) Combination of these/it varies'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' ;
  VALUE mjknew    91='(91) NEVER KNEW ANYONE WHO TRIED MARIJUANA' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     91='(91) NEVER HAD A CHANCE TO TRY MARIJUANA' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjage     91='(91) NEVER USED MARIJUANA' 94='(94) DONT KNOW' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' ;
  VALUE mjrec     1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but more than mth ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   1='(1) Less than 1 a day' 2='(2) 1 a day' 3='(3) 2-3 a day'
                  4='(4) 4-6 a day' 5='(5) 7-10 a day' 6='(6) 11 or more a day'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' ;
  VALUE mjevermt  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED MARIJUANA' 94='(94) DONT KNOW' ;
  VALUE mjaloft   1='(1) Usually' 2='(2) About half the time' 3='(3) Occasionally'
                  4='(4) Rarely' 5='(5) Never' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rxbutsol  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbutcap  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxamytal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeskab   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlumnal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmebral  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxamobar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxphnbar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxalurat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxplacid  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdorden  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnoldar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsopor   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxquaal   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxparest  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnoctec  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmthqua  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxchhyd   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnemtal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcarbr   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsecnal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtuinal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpentob  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsecob   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdalman  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsedoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxseddk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE sedbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE sedbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnosed   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsedage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxsedrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxsed15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE quaalude  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seconal   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE tuinal    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE placidyl  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE sopor     1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE nembutal  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE sednewa   0='(0) No other' 1='(1) Butisol' 2='(2) Buticaps' 3='(3) Amytal'
                  4='(4) Eskabarb' 6='(6) Mebaral' 8='(8) Phenobarbital' 11='(11) Doriden'
                  12='(12) Noludar' 15='(15) Parest' 16='(16) Noctec' 17='(17) Methaqualone'
                  18='(18) Chloral hydrate' 20='(20) Carbrital' 23='(23) Pentobarbital'
                  25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sednewb   0='(0) No other' 1='(1) Butisol' 6='(6) Mebaral' 7='(7) Amobarbital'
                  11='(11) Doriden' 15='(15) Parest' 17='(17) Methaqualone'
                  23='(23) Pentobarbital' 25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE quaa30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE seco30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE tuin30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE plac30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE sopo30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE nemb30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE sednwa3f  0='(0) No other' 4='(4) Eskabarb' 11='(11) Doriden' 17='(17) Methaqualone'
                  25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' ;
  VALUE sednwb3f  0='(0) No other' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE nosed30f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sedage    91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seddays   91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrx     1='(1) Prescribed by doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE rxvalium  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlibrum  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlibtab  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxskly    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxserax   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtranx   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxativan  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxverst   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmepros  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmiltwn  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeqnil   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmeprob  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxvistar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxatarax  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbndryl  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrnoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrndk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE trnbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE trnbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnotran  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrnage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxtrnrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxtrn15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE trnread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE valium    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE librium   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE benadryl  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE tranxene  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE equanil   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE libritab  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE trnewa    0='(0) No other' 4='(4) Sk-lygen' 5='(5) Serax' 7='(7) Ativan' 8='(8) Verstran'
                  10='(10) Miltown' 12='(12) Meprobamate' 13='(13) Vistaril' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnewb    0='(0) No other' 5='(5) Serax' 7='(7) Ativan' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE valm30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE lbrm30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE bena30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE trnx30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE eqnl30dy  2='(2) Checkmark not made'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE lbtb30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE trnewa3f  0='(0) No other' 4='(4) Sk-lygen' 7='(7) Ativan' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30'
                  94='(94) DONT KNOW' ;
  VALUE trnewb3f  0='(0) No other' 91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE notran3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE tranage   91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  94='(94) DONT KNOW' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE trandays  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnrx     1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED TRANQUILIZERS'
                  94='(94) DONT KNOW' ;
  VALUE trnmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnmark   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxdexed   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdexam   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeskat   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbenz    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbiphet  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdesox   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdetamp  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmethed  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxobla    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtenuat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtepan   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdidrex  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxplegin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxprelud  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpresat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxinamin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxponmin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxvornil  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsanrex  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxritlin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcylert  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmdk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE stmbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE stmbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnostm   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxstmrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxstm15d  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE stmread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE dexed     1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE benz      1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE biphet    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE dexamyl   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE desoxyn   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE preludin  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE stimnewa  0='(0) No other' 3='(3) Eskatrol' 7='(7) Dextroamphetamine'
                  8='(8) Methedrine' 9='(9) Obedrin-l.a.' 10='(10) Tenuate' 12='(12) Didrex'
                  13='(13) Plegine' 15='(15) Pre-sate' 16='(16) Ionamin' 18='(18) Voranil'
                  19='(19) Sanorex' 20='(20) Ritalin' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stimnewb  0='(0) No other' 3='(3) Eskatrol' 8='(8) Methedrine' 10='(10) Tenuate'
                  11='(11) Tepanil' 16='(16) Ionamin' 19='(19) Sanorex' 20='(20) Ritalin'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE dxdr30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE bndr30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE bpht30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE dxml30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE dsox30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE prel30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE stmnwa3f  0='(0) No other' 8='(8) Methedrine' 10='(10) Tenuate' 12='(12) Didrex'
                  16='(16) Ionamin' 20='(20) Ritalin' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' ;
  VALUE stmnwb3f  0='(0) No other' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE nostim3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE stimage   91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE stimdays  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrx    1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE rxdarvon  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdolene  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsk65ff  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpropox  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxleritn  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlevodr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpercod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdemrol  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdilaud  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtylcod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcodene  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdoloph  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxwestod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmethad  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtalwin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanloth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanldk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE anlbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE anlbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnoanl   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanlage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxanlrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxanl15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE anlread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE darvon    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE percodan  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE demerol   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE dilaud    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE tylcod    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE codeine   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE analnewa  0='(0) No other' 2='(2) Dolene' 3='(3) Sk-65' 4='(4) Propoxyphene'
                  5='(5) Leritine' 12='(12) Dolophine' 14='(14) Methadone' 15='(15) Talwin'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analnewb  0='(0) No other' 2='(2) Dolene' 3='(3) Sk-65' 5='(5) Leritine'
                  13='(13) Westodone' 91='(91) NEVER USED ANALGESICS' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE darv30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE perc30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE deme30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE dlau30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE tcod30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE cdne30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE anlnwa3f  0='(0) No other' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' ;
  VALUE anlnwb3f  0='(0) No other' 3='(3) Sk-65' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE analno3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analage   91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE analdays  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrx    1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE anlmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analmore  1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analstop  1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analhelp  1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE cocknew   91='(91) NEVER KNEW ANYONE WHO TRIED COCAINE' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopp    91='(91) NEVER HAD A CHANCE TO TRY COCAINE' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocage    91='(91) NEVER USED COCAINE' 94='(94) DONT KNOW' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED COCAINE'
                  94='(94) DONT KNOW' ;
  VALUE cocrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocmjoft  1='(1) Nearly every time' 2='(2) About half the time'
                  3='(3) Occasionally' 4='(4) Rarely' 5='(5) Never'
                  91='(91) NEVER USED COCAINE' 94='(94) DONT KNOW' ;
  VALUE halread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE hallknew  91='(91) NEVER KNEW ANYONE WHO TRIED HALLUCINOGEN'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   91='(91) NEVER HAD A CHANCE TO TRY HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallage   91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HALLUCINOGENS'
                  94='(94) DONT KNOW' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HALLUCINOGENS' ;
  VALUE hal30use  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halmjoft  1='(1) Nearly every time' 2='(2) About half the time'
                  3='(3) Occasionally' 4='(4) Rarely' 5='(5) Never'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than a month ago' 91='(91) NEVER USED PCP'
                  94='(94) DONT KNOW' ;
  VALUE unstahal  1='(1) Yes' 2='(2) No/not sure' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE secndoth  1='(1) Pills' 2='(2) Cocaine' 3='(3) LSD, PCP, or other hallucinogen'
                  4='(4) Other drug' 5='(5) Never tried any drug except marijuana'
                  6='(6) Marijuana was not the first one I tried'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT RECEIVE THIS ANSWER SHEET' 94='(94) DONT KNOW' ;
  VALUE secndmjr  1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times'
                  5='(5) Never tried any drug except marijuana'
                  6='(6) Marijuana was not the first one I tried'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT RECEIVE THIS ANSWER SHEET' 94='(94) DONT KNOW' ;
  VALUE herread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE herknew   91='(91) NEVER KNEW ANYONE WHO TRIED HEROIN' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heropp    91='(91) NEVER HAD A CHANCE TO TRY HEROIN' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' ;
  VALUE her30use  91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED HEROIN' ;
  VALUE fyrmjtry  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrplmtr  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrplntr  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrcoctr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrhaltr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrhertr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrnontr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE mj30buy   0='(0) None' 1='(1) 1/2 ounce or less' 2='(2) About 3/4 ounce'
                  3='(3) About 1 ounce' 4='(4) About 2 ounces' 5='(5) About 3 ounces'
                  6='(6) About 4 ounces' 7='(7) About 1/2 pound' 8='(8) Other'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj30lbs   98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjbuck    9994='(9994) DONT KNOW' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE effdeprs  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effargum  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effacdnt  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effschl   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effwork   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE odhelp    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE closfrns  0='(0) No close friends living in regular house'
                  90='(90) 90 or more' 93='(93) NOT ASKED THESE QUESTIONS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE frnsher   0='(0) No close friends living in reg household'
                  93='(93) NOT ASKED THESE QUESTIONS' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE frnsex    1='(1) Male' 2='(2) Female' 93='(93) NOT ASKED THESE QUESTIONS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frnage    1='(1) 12-17' 2='(2) 18-25' 3='(3) 26-34' 4='(4) 35+'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frntryh   1='(1) Within the past month (30 days)'
                  2='(2) Within the past year' 3='(3) More than a year ago'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frnrech   1='(1) Within the past month (30 days)'
                  2='(2) Within the past year' 3='(3) More than a year ago'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE knowuseh  1='(1) Certain' 2='(2) Probable' 3='(3) Not probable'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE othknow   0='(0) No other close friends living in reg hh'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE instate   98='(98) BLANK (NO ANSWER)' ;
  VALUE instatef  1='(1) Less than one year' 2='(2) All my life'
                  3='(3) On and off/moved in and moved out' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ethrace   1='(1) American Indian or Alaskan Native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) Hispanic'
                  5='(5) White' 6='(6) Black & Hispanic' 7='(7) Other'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hisp      1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  7='(7) Combination' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE sex       1='(1) Male' 2='(2) Female' ;
  VALUE respage   97='(97) 97 plus' ;
  VALUE ragegrp   1='(1) 18-34' 2='(2) 35+'
                  3='(3) No interview to be completed in household'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE enrlcoll  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE typeschl  1='(1) College' 2='(2) Community college' 3='(3) Vocational'
                  4='(4) Adult school' 5='(5) High school' 6='(6) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE stdftpt   1='(1) Full-time' 2='(2) Part-time' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE educ      1='(1) No schooling' 2='(2) Elementary school -- 8th grade or less'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Vocational/technical school beyond high school'
                  6='(6) Some college' 7='(7) College graduate or beyond'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE veteran   1='(1) Yes, a veteran (includes reserves)'
                  2='(2) Yes, a current member on active duty' 3='(3) No, neither'
                  4='(4) Yes, non-U S veteran' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE marital   1='(1) Married' 2='(2) Living as a couple' 3='(3) Widowed'
                  4='(4) Divorced or separated' 5='(5) Never married'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE employ3f  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE occupat   1='(1) Laborer' 2='(2) Service workers'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE nolabor   1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 6='(6) Other' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE totpeop   1='(1) Only myself' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE children  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageun12f  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE age1217f  99='(99) LEGITIMATE SKIP' ;
  VALUE age18ovr  99='(99) LEGITIMATE SKIP' ;
  VALUE hhspous   1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE numparen  99='(99) LEGITIMATE SKIP' ;
  VALUE numsibln  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE numotrel  99='(99) LEGITIMATE SKIP' ;
  VALUE numfrnds  99='(99) LEGITIMATE SKIP' ;
  VALUE numotper  99='(99) LEGITIMATE SKIP' ;
  VALUE numtot    94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Yes' 2='(2) No, respondent is chief'
                  3='(3) No wage earner in this household'
                  4='(4) Two or more equal wage earners' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cweocc    1='(1) Laborer' 2='(2) Service worker'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE military  1='(1) Yes, an active member lives here'
                  2='(2) Yes, an immediate family member is elsewhere' 4='(4) No'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE income    1='(1) No income' 2='(2) Under $10,000' 3='(3) $10,00-19,999'
                  4='(4) $20,000-29,999' 5='(5) $30,000-39,999' 6='(6) $40,000-49,999'
                  7='(7) $50,000 plus' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ytheduc   1='(1) Seventh grade or less' 2='(2) Eighth grade' 3='(3) Ninth grade'
                  4='(4) Tenth grade' 5='(5) Eleventh grade' 6='(6) Twelfth grade'
                  7='(7) Beyond high school' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ythstud   1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE ystdftpt  1='(1) Full-time' 2='(2) Part-time' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hmwrkhrs  1='(1) None' 2='(2) 5 hours or less (per week)' 3='(3) 6 to 10 hours'
                  4='(4) 11 to 20 hours' 5='(5) More than 20 hours' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE jobhours  1='(1) None' 2='(2) 5 hours or less (per week)' 3='(3) 6 to 10 hours'
                  4='(4) 11 to 20 hours' 5='(5) More than 20 hours' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE funhours  1='(1) Less than once a week' 2='(2) About once a week'
                  3='(3) Two to three times a week'
                  4='(4) Four to five times a weeks'
                  5='(5) Every night or almost every night' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE datetims  1='(1) Never' 2='(2) Once a month or less'
                  3='(3) Two to three times a month' 4='(4) About once a week'
                  5='(5) Two to three times a week' 6='(6) Four or more times a week'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ytotpeop  99='(99) LEGITIMATE SKIP' ;
  VALUE numysibs  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE numosibs  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE mother    99='(99) LEGITIMATE SKIP' ;
  VALUE father    99='(99) LEGITIMATE SKIP' ;
  VALUE ythotrel  99='(99) LEGITIMATE SKIP' ;
  VALUE ythotper  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE ynumtot   99='(99) LEGITIMATE SKIP' ;
  VALUE othsibs   1='(1) Yes' 2='(2) No' 3='(3) Step-siblings' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ythcwe3f  1='(1) Yes' 2='(2) No' 3='(3) No chief wage earner'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ythoccup  1='(1) Laborer' 2='(2) Service worker'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ynolabor  1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 6='(6) Other' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ythmltry  1='(1) Yes, an active member lives here'
                  2='(2) Yes, an immediate family member elsewhere' 3='(3) Both'
                  4='(4) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE intmo     1='(1) November' 2='(2) December' 3='(3) March' 4='(4) April' 5='(5) May'
                  6='(6) June' 7='(7) July' 9='(9) February' 94='(94) DONT KNOW' ;
  VALUE intda     94='(94) DONT KNOW' ;
  VALUE hharea    1='(1) City' 2='(2) Town' 3='(3) Suburbs' 4='(4) Village' 5='(5) Rural'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE undint    1='(1) No difficulty -- No language or reading problem'
                  2='(2) Just a little difficulty -- Almost no lang prob'
                  3='(3) A fair amount of difficulty -- Some lang/read prob'
                  4='(4) A lot of difficulty -- Considerable lang/read prob'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very' 2='(2) Fairly' 3='(3) Not very' 4='(4) Hostile'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE estrace   1='(1) Black' 2='(2) White' 3='(3) Other' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private'
                  3='(3) Minor distractions by parent/older person'
                  5='(5) Parent/older person in room 1/3 of time'
                  7='(7) Serious interruptions more than 1/2 of time'
                  9='(9) Constant presence of parent/older person' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE quextype  1='(1) Core' 2='(2) Form N' ;
  VALUE adultyth  1='(1) Adult' 2='(2) Youth' ;
  VALUE adltqcd   1='(1) Core' 2='(2) Form N' ;
  VALUE tothhvis  94='(94) DONT KNOW' ;
  VALUE finlresf  0='(0) Respondent not at home' 1='(1) Completed interview'
                  4='(4) Instruction is do not interview'
                  8='(8) No record; face sheet not returned'
                  9='(9) Respondent refused' 94='(94) DONT KNOW' 97='(97) REFUSED' ;
  VALUE vsadltcm  0='(0) No adult interview' 94='(94) DONT KNOW' ;
  VALUE phadltcm  0='(0) No adult interview' 1='(1) Original assignment'
                  2='(2) Reassignment' 94='(94) DONT KNOW' ;
  VALUE vsythcm   94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phythcm   0='(0) Interview not complete' 1='(1) Original assignment'
                  2='(2) Reassignment' 94='(94) DONT KNOW' ;
  VALUE division  1='(1) North East (New England)'
                  2='(2) North East (Middle Atlantic)'
                  3='(3) North Central (East North Central)'
                  4='(4) North Central (West North Central)'
                  5='(5) South (South Atlantic)' 6='(6) South (East South Central)'
                  7='(7) South (West South Central)' 8='(8) West (Mountain)'
                  9='(9) West (Pacific)' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE popdenx   1='(1) Segment in a self-representing SMSA'
                  2='(2) Segment in a non-self-representing SMSA'
                  3='(3) Segment not in a SMSA' ;
  VALUE iiage     1='(1) Age from source file' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from source file' ;
  VALUE irracex   1='(1) American Indian or Alaskan native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) White'
                  5='(5) Hispanic' ;
  VALUE iiracex   1='(1) Race from source file' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Non-Hispanic' ;
  VALUE iihoind   1='(1) Hispanicity from source file' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group from source file'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Never married' 5='(5) Cohabitating' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Marital status from source file'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE ireduc    1='(1) No schooling' 2='(2) Less than 8th grade'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Vocational/technical school' 6='(6) Some college'
                  7='(7) College graduate/Some graduate school'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iieduc    1='(1) Education from source file' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but more than a month ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but more than a month ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past months (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtranrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used tranquilizers' ;
  VALUE iitranrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstimrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used stimulants' ;
  VALUE iistimrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranalrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used analgesics' ;
  VALUE iianalrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) In the past 30 days' 2='(2) Within the past six months'
                  3='(3) Within the past year' 4='(4) More than a year ago'
                  9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhallrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used hallucinogens' ;
  VALUE iihallrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)' 2='(2) More than month ago'
                  9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' ;
  VALUE catage    1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26-34 years old'
                  4='(4) 35+ years old' ;
  VALUE catag2ff  1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26+ years old' ;
  VALUE catag3ff  1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26-34 years old'
                  4='(4) 35-49 years old' 5='(5) 50+ years old' ;
  VALUE race      1='(1) White (IRRACE = 5 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 6 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-4 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Non-Hispanic Black'
                  3='(3) Non-Hispanic Non-Black' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=1-3 and IRAGE=>18'
                  2='(2) High school graduate (IREDUC = 4 and IRAGE=>18'
                  3='(3) Some college/postsec (IREDUC=5-6 and IRAGE=>18'
                  4='(4) College graduate (IREDUC = 7 and IRAGE=>18'
                  5='(5) 12-17 years old (IRAGE = 12-17)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-4)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC = 4,9)'
                  1='(1) Used within the past year (IRHALRC = 1-3' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC = 2-4, 9)'
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-2)' ;
  VALUE pcpyrx    0='(0) Did not use in the past year (IRPCPRC = 2, 9)'
                  1='(1) Used within the past year (IRPCPRC = 1)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC = 2, 9)'
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-4)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC = 4, 9)'
                  1='(1) Used within the past year (IRSTMRC = 1-3' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC = 2-4, 9)'
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-4)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC = 4, 9)'
                  1='(1) Used within the past year (IRSEDRC = 1-3' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC = 2-4, 9)'
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-4)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC = 4, 9)'
                  1='(1) Used within the past year (IRTRNRC = 1-3' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC = 2-4, 9)'
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-4)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC = 4, 9)'
                  1='(1) Used within the past year (IRANLRC = 1-3' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC = 2-4, 9)'
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-4)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC = 4, 9)'
                  1='(1) Used within the past year (IRALCRC = 1-3' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC = 2-4, 9)'
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-4)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC = 4, 9)'
                  1='(1) Used within the past year (IRCIGRC = 1-3' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC = 2-4, 9)'
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-4)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC = 4, 9)'
                  1='(1) Used within the past year (IRHERRC = 1-3' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC = 2-4, 9)'
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-4)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 4, 9)'
                  1='(1) Used within the past year (IRMJRC = 1-3)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC = 2-4, 9)'
                  1='(1) Used within the past month (IRMJRC = 1)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-4)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC = 4, 9)'
                  1='(1) Used within the past year (IRCOCRC = 1-3' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC = 2-4, 9)'
                  1='(1) Used within the past month (IRCOCRC = 1)' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE > 3)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE < 4)' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VARS > 1)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumflagx  0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyrx    0='(0) Did not use in past year (ALL SOURCE VARS = 0)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE = 1)' ;
  VALUE summonx   0='(0) Did not use in past month (ALL SOURCE VARS = 0)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE mjoflagx  0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2x   0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2x  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE iemflagx  0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ever used' ;
  VALUE iemyrx    0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmonx   0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGMORLS >= 81) THEN CIGMORLS = .;
   IF (CIGTRY >= 81) THEN CIGTRY = .;
   IF (CIG5PK >= 81) THEN CIG5PK = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (MORLSMJ >= 81) THEN MORLSMJ = .;
   IF (MORLSSED >= 81) THEN MORLSSED = .;
   IF (MORLSTRN >= 81) THEN MORLSTRN = .;
   IF (MORLSAMP >= 81) THEN MORLSAMP = .;
   IF (MORLSCOC >= 81) THEN MORLSCOC = .;
   IF (MORLSLSD >= 81) THEN MORLSLSD = .;
   IF (MORLSHER >= 81) THEN MORLSHER = .;
   IF (ALCTRY >= 81) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (ALCPREF >= 81) THEN ALCPREF = .;
   IF (MJKNEW >= 81) THEN MJKNEW = .;
   IF (MJOPP >= 81) THEN MJOPP = .;
   IF (MJAGE >= 81) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJEVERMT >= 81) THEN MJEVERMT = .;
   IF (MJALOFT >= 81) THEN MJALOFT = .;
   IF (SEDBOR30 >= 81) THEN SEDBOR30 = .;
   IF (RXSEDAGE >= 81) THEN RXSEDAGE = .;
   IF (RXSEDREC >= 81) THEN RXSEDREC = .;
   IF (RXSED15D >= 81) THEN RXSED15D = .;
   IF (QUAALUDE >= 81) THEN QUAALUDE = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (SOPOR >= 81) THEN SOPOR = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (SEDNEWA >= 81) THEN SEDNEWA = .;
   IF (SEDNEWB >= 81) THEN SEDNEWB = .;
   IF (QUAA30DY >= 81) THEN QUAA30DY = .;
   IF (SECO30DY >= 81) THEN SECO30DY = .;
   IF (TUIN30DY >= 81) THEN TUIN30DY = .;
   IF (PLAC30DY >= 81) THEN PLAC30DY = .;
   IF (SOPO30DY >= 81) THEN SOPO30DY = .;
   IF (NEMB30DY >= 81) THEN NEMB30DY = .;
   IF (SEDNWA30 >= 81) THEN SEDNWA30 = .;
   IF (SEDNWB30 >= 81) THEN SEDNWB30 = .;
   IF (NOSED30 >= 81) THEN NOSED30 = .;
   IF (SEDAGE >= 81) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDDAYS >= 81) THEN SEDDAYS = .;
   IF (SEDRX >= 81) THEN SEDRX = .;
   IF (SEDMJOCC >= 81) THEN SEDMJOCC = .;
   IF (SEDMORE >= 81) THEN SEDMORE = .;
   IF (SEDSTOP >= 81) THEN SEDSTOP = .;
   IF (SEDHELP >= 81) THEN SEDHELP = .;
   IF (TRNBOR30 >= 81) THEN TRNBOR30 = .;
   IF (RXTRNAGE >= 81) THEN RXTRNAGE = .;
   IF (RXTRNREC >= 81) THEN RXTRNREC = .;
   IF (RXTRN15D >= 81) THEN RXTRN15D = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (BENADRYL >= 81) THEN BENADRYL = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (EQUANIL >= 81) THEN EQUANIL = .;
   IF (LIBRITAB >= 81) THEN LIBRITAB = .;
   IF (TRNEWA >= 81) THEN TRNEWA = .;
   IF (TRNEWB >= 81) THEN TRNEWB = .;
   IF (VALM30DY >= 81) THEN VALM30DY = .;
   IF (LBRM30DY >= 81) THEN LBRM30DY = .;
   IF (BENA30DY >= 81) THEN BENA30DY = .;
   IF (TRNX30DY >= 81) THEN TRNX30DY = .;
   IF (EQNL30DY >= 81) THEN EQNL30DY = .;
   IF (LBTB30DY >= 81) THEN LBTB30DY = .;
   IF (TRNEWA30 >= 81) THEN TRNEWA30 = .;
   IF (TRNEWB30 >= 81) THEN TRNEWB30 = .;
   IF (NOTRAN30 >= 81) THEN NOTRAN30 = .;
   IF (TRANAGE >= 81) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRANDAYS >= 81) THEN TRANDAYS = .;
   IF (TRNRX >= 81) THEN TRNRX = .;
   IF (TRNMJOCC >= 81) THEN TRNMJOCC = .;
   IF (TRNMORE >= 81) THEN TRNMORE = .;
   IF (TRNSTOP >= 81) THEN TRNSTOP = .;
   IF (TRNHELP >= 81) THEN TRNHELP = .;
   IF (TRNMARK >= 81) THEN TRNMARK = .;
   IF (STMBOR30 >= 81) THEN STMBOR30 = .;
   IF (RXSTMAGE >= 81) THEN RXSTMAGE = .;
   IF (RXSTMREC >= 81) THEN RXSTMREC = .;
   IF (RXSTM15D >= 81) THEN RXSTM15D = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (DESOXYN >= 81) THEN DESOXYN = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (STIMNEWA >= 81) THEN STIMNEWA = .;
   IF (STIMNEWB >= 81) THEN STIMNEWB = .;
   IF (DXDR30DY >= 81) THEN DXDR30DY = .;
   IF (BNDR30DY >= 81) THEN BNDR30DY = .;
   IF (BPHT30DY >= 81) THEN BPHT30DY = .;
   IF (DXML30DY >= 81) THEN DXML30DY = .;
   IF (DSOX30DY >= 81) THEN DSOX30DY = .;
   IF (PREL30DY >= 81) THEN PREL30DY = .;
   IF (STMNWA30 >= 81) THEN STMNWA30 = .;
   IF (STMNWB30 >= 81) THEN STMNWB30 = .;
   IF (NOSTIM30 >= 81) THEN NOSTIM30 = .;
   IF (STIMAGE >= 81) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STIMDAYS >= 81) THEN STIMDAYS = .;
   IF (STIMRX >= 81) THEN STIMRX = .;
   IF (STMMJOCC >= 81) THEN STMMJOCC = .;
   IF (STMMORE >= 81) THEN STMMORE = .;
   IF (STMSTOP >= 81) THEN STMSTOP = .;
   IF (STMHELP >= 81) THEN STMHELP = .;
   IF (ANLBOR30 >= 81) THEN ANLBOR30 = .;
   IF (RXANLAGE >= 94) THEN RXANLAGE = .;
   IF (RXANLREC >= 81) THEN RXANLREC = .;
   IF (RXANL15D >= 81) THEN RXANL15D = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (ANALNEWA >= 81) THEN ANALNEWA = .;
   IF (ANALNEWB >= 81) THEN ANALNEWB = .;
   IF (DARV30DY >= 81) THEN DARV30DY = .;
   IF (PERC30DY >= 81) THEN PERC30DY = .;
   IF (DEME30DY >= 81) THEN DEME30DY = .;
   IF (DLAU30DY >= 81) THEN DLAU30DY = .;
   IF (TCOD30DY >= 81) THEN TCOD30DY = .;
   IF (CDNE30DY >= 81) THEN CDNE30DY = .;
   IF (ANLNWA30 >= 81) THEN ANLNWA30 = .;
   IF (ANLNWB30 >= 81) THEN ANLNWB30 = .;
   IF (ANALNO30 >= 81) THEN ANALNO30 = .;
   IF (ANALAGE >= 81) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANALDAYS >= 81) THEN ANALDAYS = .;
   IF (ANALRX >= 81) THEN ANALRX = .;
   IF (ANLMJOCC >= 81) THEN ANLMJOCC = .;
   IF (ANALMORE >= 81) THEN ANALMORE = .;
   IF (ANALSTOP >= 81) THEN ANALSTOP = .;
   IF (ANALHELP >= 81) THEN ANALHELP = .;
   IF (COCKNEW >= 81) THEN COCKNEW = .;
   IF (COCOPP >= 81) THEN COCOPP = .;
   IF (COCAGE >= 81) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (COCMJOFT >= 81) THEN COCMJOFT = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (HALLKNEW >= 81) THEN HALLKNEW = .;
   IF (HALLOPP >= 81) THEN HALLOPP = .;
   IF (HALLAGE >= 81) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HALMJOFT >= 81) THEN HALMJOFT = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (UNSTAHAL >= 81) THEN UNSTAHAL = .;
   IF (SECNDOTH >= 81) THEN SECNDOTH = .;
   IF (SECNDMJR >= 81) THEN SECNDMJR = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HERKNEW >= 81) THEN HERKNEW = .;
   IF (HEROPP >= 81) THEN HEROPP = .;
   IF (HERAGE >= 81) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (FYRMJTRY >= 81) THEN FYRMJTRY = .;
   IF (FYRPLMTR >= 81) THEN FYRPLMTR = .;
   IF (FYRPLNTR >= 81) THEN FYRPLNTR = .;
   IF (MJ30BUY >= 81) THEN MJ30BUY = .;
   IF (MJ30LBS >= 98) THEN MJ30LBS = .;
   IF (MJBUCK >= 9994) THEN MJBUCK = .;
   IF (EFFDEPRS >= 81) THEN EFFDEPRS = .;
   IF (EFFARGUM >= 81) THEN EFFARGUM = .;
   IF (EFFACDNT >= 81) THEN EFFACDNT = .;
   IF (EFFSCHL >= 81) THEN EFFSCHL = .;
   IF (EFFWORK >= 81) THEN EFFWORK = .;
   IF (ODHELP >= 81) THEN ODHELP = .;
   IF (CLOSFRNS >= 93) THEN CLOSFRNS = .;
   IF (FRNSHER >= 81) THEN FRNSHER = .;
   IF (FRNSEX >= 81) THEN FRNSEX = .;
   IF (FRNAGE >= 81) THEN FRNAGE = .;
   IF (FRNTRYH >= 81) THEN FRNTRYH = .;
   IF (FRNRECH >= 81) THEN FRNRECH = .;
   IF (KNOWUSEH >= 81) THEN KNOWUSEH = .;
   IF (OTHKNOW >= 81) THEN OTHKNOW = .;
   IF (INSTATE >= 81) THEN INSTATE = .;
   IF (INSTATE2 >= 81) THEN INSTATE2 = .;
   IF (ETHRACE >= 81) THEN ETHRACE = .;
   IF (HISP >= 81) THEN HISP = .;
   IF (RAGEGRP >= 81) THEN RAGEGRP = .;
   IF (ENRLCOLL >= 81) THEN ENRLCOLL = .;
   IF (TYPESCHL >= 81) THEN TYPESCHL = .;
   IF (STDFTPT >= 81) THEN STDFTPT = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (VETERAN >= 81) THEN VETERAN = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (EMPLOY30 >= 81) THEN EMPLOY30 = .;
   IF (OCCUPAT >= 81) THEN OCCUPAT = .;
   IF (NOLABOR >= 81) THEN NOLABOR = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (CHILDREN >= 81) THEN CHILDREN = .;
   IF (AGEUN12 >= 81) THEN AGEUN12 = .;
   IF (AGE1217 >= 81) THEN AGE1217 = .;
   IF (AGE18OVR >= 81) THEN AGE18OVR = .;
   IF (HHSPOUS >= 81) THEN HHSPOUS = .;
   IF (NUMPAREN >= 81) THEN NUMPAREN = .;
   IF (NUMSIBLN >= 81) THEN NUMSIBLN = .;
   IF (NUMOTREL >= 81) THEN NUMOTREL = .;
   IF (NUMFRNDS >= 81) THEN NUMFRNDS = .;
   IF (NUMOTPER >= 81) THEN NUMOTPER = .;
   IF (NUMTOT >= 81) THEN NUMTOT = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWEOCC >= 81) THEN CWEOCC = .;
   IF (MILITARY >= 81) THEN MILITARY = .;
   IF (INCOME >= 81) THEN INCOME = .;
   IF (YTHEDUC >= 81) THEN YTHEDUC = .;
   IF (YTHSTUD >= 81) THEN YTHSTUD = .;
   IF (YSTDFTPT >= 81) THEN YSTDFTPT = .;
   IF (HMWRKHRS >= 81) THEN HMWRKHRS = .;
   IF (JOBHOURS >= 81) THEN JOBHOURS = .;
   IF (FUNHOURS >= 81) THEN FUNHOURS = .;
   IF (DATETIMS >= 81) THEN DATETIMS = .;
   IF (YTOTPEOP >= 81) THEN YTOTPEOP = .;
   IF (NUMYSIBS >= 81) THEN NUMYSIBS = .;
   IF (NUMOSIBS >= 81) THEN NUMOSIBS = .;
   IF (MOTHER >= 81) THEN MOTHER = .;
   IF (FATHER >= 81) THEN FATHER = .;
   IF (YTHOTREL >= 81) THEN YTHOTREL = .;
   IF (YTHOTPER >= 81) THEN YTHOTPER = .;
   IF (YNUMTOT >= 81) THEN YNUMTOT = .;
   IF (OTHSIBS >= 81) THEN OTHSIBS = .;
   IF (YTHCWE30 >= 81) THEN YTHCWE30 = .;
   IF (YTHOCCUP >= 81) THEN YTHOCCUP = .;
   IF (YNOLABOR >= 81) THEN YNOLABOR = .;
   IF (YTHMLTRY >= 81) THEN YTHMLTRY = .;
   IF (INTMO >= 81) THEN INTMO = .;
   IF (INTDA >= 81) THEN INTDA = .;
   IF (HHAREA >= 81) THEN HHAREA = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (ESTRACE >= 81) THEN ESTRACE = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (TOTHHVIS >= 81) THEN TOTHHVIS = .;
   IF (FINLRES1 >= 81) THEN FINLRES1 = .;
   IF (VSADLTCM >= 81) THEN VSADLTCM = .;
   IF (PHADLTCM >= 81) THEN PHADLTCM = .;
   IF (VSYTHCM >= 81) THEN VSYTHCM = .;
   IF (PHYTHCM >= 81) THEN PHYTHCM = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IREDUC >= 81) THEN IREDUC = .;
   IF (IIEDUC >= 9) THEN IIEDUC = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRANRC >= 9) THEN IRTRANRC = .;
   IF (IRSTIMRC >= 9) THEN IRSTIMRC = .;
   IF (IRANALRC >= 9) THEN IRANALRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IRHALLRC >= 9) THEN IRHALLRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CIGMORLS cigmorls. CIGTRY cigtry. CIG5PK cig5pk.
         CIGREC cigrec. AVCIG avcig. MORLSMJ morlsmj.
         MORLSSED morlssed. MORLSTRN morlstrn. MORLSAMP morlsamp.
         MORLSCOC morlscoc. MORLSLSD morlslsd. MORLSHER morlsher.
         ADDALC addalc. ADDMJ addmj. ADDSED addsed.
         ADDTRAN addtran. ADDAMP addamp. ADDCOC addcoc.
         ADDLSD addlsd. ADDHER addher. ADDNONE addnone.
         ALCTRY alctry. ALCREC alcrec. ALCDAYS alcdays.
         ALCPREF alcpref. MJKNEW mjknew. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJEVERMT mjevermt.
         MJALOFT mjaloft. RXBUTSOL rxbutsol. RXBUTCAP rxbutcap.
         RXAMYTAL rxamytal. RXESKAB rxeskab. RXLUMNAL rxlumnal.
         RXMEBRAL rxmebral. RXAMOBAR rxamobar. RXPHNBAR rxphnbar.
         RXALURAT rxalurat. RXPLACID rxplacid. RXDORDEN rxdorden.
         RXNOLDAR rxnoldar. RXSOPOR rxsopor. RXQUAAL rxquaal.
         RXPAREST rxparest. RXNOCTEC rxnoctec. RXMTHQUA rxmthqua.
         RXCHHYD rxchhyd. RXNEMTAL rxnemtal. RXCARBR rxcarbr.
         RXSECNAL rxsecnal. RXTUINAL rxtuinal. RXPENTOB rxpentob.
         RXSECOB rxsecob. RXDALMAN rxdalman. RXSEDOTH rxsedoth.
         RXSEDDK rxseddk. SEDBOR sedbor. SEDBOR30 sedbor3f.
         RXNOSED rxnosed. RXSEDAGE rxsedage. RXSEDREC rxsedrec.
         RXSED15D rxsed15d. QUAALUDE quaalude. SECONAL seconal.
         TUINAL tuinal. PLACIDYL placidyl. SOPOR sopor.
         NEMBUTAL nembutal. SEDNEWA sednewa. SEDNEWB sednewb.
         NOSEDAT nosedat. QUAA30DY quaa30dy. SECO30DY seco30dy.
         TUIN30DY tuin30dy. PLAC30DY plac30dy. SOPO30DY sopo30dy.
         NEMB30DY nemb30dy. SEDNWA30 sednwa3f. SEDNWB30 sednwb3f.
         NOSED30 nosed30f. SEDAGE sedage. SEDTOT sedtot.
         SEDREC sedrec. SEDDAYS seddays. SEDRX sedrx.
         SEDMJOCC sedmjocc. SEDMORE sedmore. SEDSTOP sedstop.
         SEDHELP sedhelp. RXVALIUM rxvalium. RXLIBRUM rxlibrum.
         RXLIBTAB rxlibtab. RXSKLY rxskly. RXSERAX rxserax.
         RXTRANX rxtranx. RXATIVAN rxativan. RXVERST rxverst.
         RXMEPROS rxmepros. RXMILTWN rxmiltwn. RXEQNIL rxeqnil.
         RXMEPROB rxmeprob. RXVISTAR rxvistar. RXATARAX rxatarax.
         RXBNDRYL rxbndryl. RXTRNOTH rxtrnoth. RXTRNDK rxtrndk.
         TRNBOR trnbor. TRNBOR30 trnbor3f. RXNOTRAN rxnotran.
         RXTRNAGE rxtrnage. RXTRNREC rxtrnrec. RXTRN15D rxtrn15d.
         TRNREAD trnread. VALIUM valium. LIBRIUM librium.
         BENADRYL benadryl. TRANXENE tranxene. EQUANIL equanil.
         LIBRITAB libritab. TRNEWA trnewa. TRNEWB trnewb.
         NOTRANQ notranq. VALM30DY valm30dy. LBRM30DY lbrm30dy.
         BENA30DY bena30dy. TRNX30DY trnx30dy. EQNL30DY eqnl30dy.
         LBTB30DY lbtb30dy. TRNEWA30 trnewa3f. TRNEWB30 trnewb3f.
         NOTRAN30 notran3f. TRANAGE tranage. TRANTOT trantot.
         TRANREC tranrec. TRANDAYS trandays. TRNRX trnrx.
         TRNMJOCC trnmjocc. TRNMORE trnmore. TRNSTOP trnstop.
         TRNHELP trnhelp. TRNMARK trnmark. RXDEXED rxdexed.
         RXDEXAM rxdexam. RXESKAT rxeskat. RXBENZ rxbenz.
         RXBIPHET rxbiphet. RXDESOX rxdesox. RXDETAMP rxdetamp.
         RXMETHED rxmethed. RXOBLA rxobla. RXTENUAT rxtenuat.
         RXTEPAN rxtepan. RXDIDREX rxdidrex. RXPLEGIN rxplegin.
         RXPRELUD rxprelud. RXPRESAT rxpresat. RXINAMIN rxinamin.
         RXPONMIN rxponmin. RXVORNIL rxvornil. RXSANREX rxsanrex.
         RXRITLIN rxritlin. RXCYLERT rxcylert. RXSTMOTH rxstmoth.
         RXSTMDK rxstmdk. STMBOR stmbor. STMBOR30 stmbor3f.
         RXNOSTM rxnostm. RXSTMAGE rxstmage. RXSTMREC rxstmrec.
         RXSTM15D rxstm15d. STMREAD stmread. DEXED dexed.
         BENZ benz. BIPHET biphet. DEXAMYL dexamyl.
         DESOXYN desoxyn. PRELUDIN preludin. STIMNEWA stimnewa.
         STIMNEWB stimnewb. NOSTIMS nostims. DXDR30DY dxdr30dy.
         BNDR30DY bndr30dy. BPHT30DY bpht30dy. DXML30DY dxml30dy.
         DSOX30DY dsox30dy. PREL30DY prel30dy. STMNWA30 stmnwa3f.
         STMNWB30 stmnwb3f. NOSTIM30 nostim3f. STIMAGE stimage.
         STIMTOT stimtot. STIMREC stimrec. STIMDAYS stimdays.
         STIMRX stimrx. STMMJOCC stmmjocc. STMMORE stmmore.
         STMSTOP stmstop. STMHELP stmhelp. RXDARVON rxdarvon.
         RXDOLENE rxdolene. RXSK65 rxsk65ff. RXPROPOX rxpropox.
         RXLERITN rxleritn. RXLEVODR rxlevodr. RXPERCOD rxpercod.
         RXDEMROL rxdemrol. RXDILAUD rxdilaud. RXTYLCOD rxtylcod.
         RXCODENE rxcodene. RXDOLOPH rxdoloph. RXWESTOD rxwestod.
         RXMETHAD rxmethad. RXTALWIN rxtalwin. RXANLOTH rxanloth.
         RXANLDK rxanldk. ANLBOR anlbor. ANLBOR30 anlbor3f.
         RXNOANL rxnoanl. RXANLAGE rxanlage. RXANLREC rxanlrec.
         RXANL15D rxanl15d. ANLREAD anlread. DARVON darvon.
         PERCODAN percodan. DEMEROL demerol. DILAUD dilaud.
         TYLCOD tylcod. CODEINE codeine. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNONE analnone. DARV30DY darv30dy.
         PERC30DY perc30dy. DEME30DY deme30dy. DLAU30DY dlau30dy.
         TCOD30DY tcod30dy. CDNE30DY cdne30dy. ANLNWA30 anlnwa3f.
         ANLNWB30 anlnwb3f. ANALNO30 analno3f. ANALAGE analage.
         ANALTOT analtot. ANALREC analrec. ANALDAYS analdays.
         ANALRX analrx. ANLMJOCC anlmjocc. ANALMORE analmore.
         ANALSTOP analstop. ANALHELP analhelp. COCKNEW cocknew.
         COCOPP cocopp. COCAGE cocage. COCTOT coctot.
         COCREC cocrec. COCUS30A cocus30a. COCMJOFT cocmjoft.
         HALREAD halread. HALLKNEW hallknew. HALLOPP hallopp.
         HALLAGE hallage. HALLTOT halltot. HALLREC hallrec.
         HAL30USE hal30use. HALMJOFT halmjoft. PCP pcp.
         PCPREC pcprec. UNSTAHAL unstahal. SECNDOTH secndoth.
         SECNDMJR secndmjr. HERREAD herread. HERKNEW herknew.
         HEROPP heropp. HERAGE herage. HERTOT hertot.
         HERREC herrec. HER30USE her30use. HERNEEDL herneedl.
         FYRMJTRY fyrmjtry. FYRPLMTR fyrplmtr. FYRPLNTR fyrplntr.
         FYRCOCTR fyrcoctr. FYRHALTR fyrhaltr. FYRHERTR fyrhertr.
         FYRNONTR fyrnontr. MJ30BUY mj30buy. MJ30LBS mj30lbs.
         MJBUCK mjbuck. EFFDEPRS effdeprs. EFFARGUM effargum.
         EFFACDNT effacdnt. EFFSCHL effschl. EFFWORK effwork.
         ODHELP odhelp. CLOSFRNS closfrns. FRNSHER frnsher.
         FRNSEX frnsex. FRNAGE frnage. FRNTRYH frntryh.
         FRNRECH frnrech. KNOWUSEH knowuseh. OTHKNOW othknow.
         INSTATE instate. INSTATE2 instatef. ETHRACE ethrace.
         HISP hisp. SEX sex. RESPAGE respage.
         RAGEGRP ragegrp. ENRLCOLL enrlcoll. TYPESCHL typeschl.
         STDFTPT stdftpt. EDUC educ. VETERAN veteran.
         MARITAL marital. EMPLOY30 employ3f. OCCUPAT occupat.
         NOLABOR nolabor. TOTPEOP totpeop. CHILDREN children.
         AGEUN12 ageun12f. AGE1217 age1217f. AGE18OVR age18ovr.
         HHSPOUS hhspous. NUMPAREN numparen. NUMSIBLN numsibln.
         NUMOTREL numotrel. NUMFRNDS numfrnds. NUMOTPER numotper.
         NUMTOT numtot. CWE cwe. CWEOCC cweocc.
         MILITARY military. INCOME income. YTHEDUC ytheduc.
         YTHSTUD ythstud. YSTDFTPT ystdftpt. HMWRKHRS hmwrkhrs.
         JOBHOURS jobhours. FUNHOURS funhours. DATETIMS datetims.
         YTOTPEOP ytotpeop. NUMYSIBS numysibs. NUMOSIBS numosibs.
         MOTHER mother. FATHER father. YTHOTREL ythotrel.
         YTHOTPER ythotper. YNUMTOT ynumtot. OTHSIBS othsibs.
         YTHCWE30 ythcwe3f. YTHOCCUP ythoccup. YNOLABOR ynolabor.
         YTHMLTRY ythmltry. INTMO intmo. INTDA intda.
         HHAREA hharea. UNDINT undint. COOPINT coopint.
         ESTRACE estrace. PRIVACY privacy. QUEXTYPE quextype.
         ADULTYTH adultyth. ADLTQCD adltqcd. TOTHHVIS tothhvis.
         FINLRES1 finlresf. VSADLTCM vsadltcm. PHADLTCM phadltcm.
         VSYTHCM vsythcm. PHYTHCM phythcm. DIVISION division.
         REGION region. POPDENX popdenx. IIAGE iiage.
         IRSEX irsex. IISEX iisex. IRRACEX irracex.
         IIRACEX iiracex. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRMARIT irmarit.
         IIMARIT iimarit. IREDUC ireduc. IIEDUC iieduc.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRTRANRC irtranrc.
         IITRANRC iitranrc. IRSTIMRC irstimrc. IISTIMRC iistimrc.
         IRANALRC iranalrc. IIANALRC iianalrc. IRCIGRC ircigrc.
         IICIGRC iicigrc. IRHALLRC irhallrc. IIHALLRC iihallrc.
         IRHERRC irherrc. IIHERRC iiherrc. IRPCPRC irpcprc.
         IIPCPRC iipcprc. CATAGE catage. CATAG2 catag2ff.
         CATAG3 catag3ff. RACE race. HISPRACE hisprace.
         EDUCCAT2 educcatf. HALFLAG halflag. HALYR halyr.
         HALMON halmon. PCPFLAG pcpflag. PCPYRX pcpyrx.
         PCPMON pcpmon. STMFLAG stmflag. STMYR stmyr.
         STMMON stmmon. SEDFLAG sedflag. SEDYR sedyr.
         SEDMON sedmon. TRQFLAG trqflag. TRQYR trqyr.
         TRQMON trqmon. ANLFLAG anlflag. ANLYR anlyr.
         ANLMON anlmon. ALCFLAG alcflag. ALCYR alcyr.
         ALCMON alcmon. CIGFLAG cigflag. CIGYR cigyr.
         CIGMON cigmon. HERFLAG herflag. HERYR heryr.
         HERMON hermon. MRJFLAG mrjflag. MRJYR mrjyr.
         MRJMON mrjmon. COCFLAG cocflag. COCYR cocyr.
         COCMON cocmon. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAGX sumflagx. SUMYRX sumyrx.
         SUMMONX summonx. MJOFLAGX mjoflagx. MJOYR2X mjoyr2x.
         MJOMON2X mjomon2x. IEMFLAGX iemflagx. IEMYRX iemyrx.
         IEMMONX iemmonx.  ;

RUN ;
